Share and Enjoy
===============

This package would not have been possible without the contribution of the following people:

- Héctor Velarde
- Rodrigo Ferreira de Souza
- Katja Süss, Rohberg, @ksuess
